import { IRepositoryId } from "./repository-id";
import { EventStorage } from "./event-storage";
export declare type SemVer = string;
interface IOSInfo {
    nodeVersion: SemVer;
    platform: string;
    release: string;
    cpus: string | undefined;
    arch: string;
    ci: boolean | undefined;
    ciName: string | null;
    docker: boolean | undefined;
}
export interface IAggregateStats {
    count: number;
    min: number;
    max: number;
    sum: number;
    mean: number;
    median: number;
    stdDev: number;
    skewness: number;
}
interface IAnalyticsTrackerConstructorParameters {
    componentId?: SemVer;
    gatsbyCliVersion?: SemVer;
}
export interface IStructuredError {
    id?: string;
    code?: string;
    text: string;
    level?: string;
    type?: string;
    context?: unknown;
    error?: {
        stack?: string;
    };
}
export interface IStructuredErrorV2 {
    id?: string;
    text: string;
    level?: string;
    type?: string;
    context?: string;
    stack?: string;
}
export interface ITelemetryTagsPayload {
    name?: string;
    starterName?: string;
    pluginName?: string;
    exitCode?: number;
    duration?: number;
    uiSource?: string;
    valid?: boolean;
    plugins?: Array<string>;
    pathname?: string;
    error?: IStructuredError | Array<IStructuredError>;
    cacheStatus?: string;
    pluginCachePurged?: string;
    siteMeasurements?: {
        pagesCount?: number;
        clientsCount?: number;
        paths?: Array<string | undefined>;
        bundleStats?: unknown;
        pageDataStats?: unknown;
        queryStats?: unknown;
    };
    errorV2?: IStructuredErrorV2;
}
export interface IDefaultTelemetryTagsPayload extends ITelemetryTagsPayload {
    gatsbyCliVersion?: SemVer;
    installedGatsbyVersion?: SemVer;
}
export interface ITelemetryOptsPayload {
    debounce?: boolean;
}
export declare class AnalyticsTracker {
    store: EventStorage;
    componentId: string;
    debouncer: {};
    metadataCache: {};
    defaultTags: {};
    osInfo?: IOSInfo;
    trackingEnabled?: boolean;
    componentVersion?: string;
    sessionId: string;
    gatsbyCliVersion?: SemVer;
    installedGatsbyVersion?: SemVer;
    repositoryId?: IRepositoryId;
    features: Set<string>;
    machineId: string;
    constructor({ componentId, gatsbyCliVersion, }?: IAnalyticsTrackerConstructorParameters);
    getSessionId(): string;
    getRepositoryId(): IRepositoryId;
    getTagsFromEnv(): Record<string, unknown>;
    getGatsbyVersion(): SemVer;
    getGatsbyCliVersion(): SemVer;
    captureEvent(type?: string | Array<string>, tags?: ITelemetryTagsPayload, opts?: ITelemetryOptsPayload): void;
    isFinalEvent(event: string): boolean;
    captureError(type: string, tags?: ITelemetryTagsPayload): void;
    captureBuildError(type: string, tags?: ITelemetryTagsPayload): void;
    formatErrorAndStoreEvent(eventType: string, tags: ITelemetryTagsPayload): void;
    buildAndStoreEvent(eventType: string, tags: ITelemetryTagsPayload): void;
    getMachineId(): string;
    isTrackingEnabled(): boolean;
    getOsInfo(): IOSInfo;
    trackActivity(source: string): void;
    decorateNextEvent(event: string, obj: any): void;
    addSiteMeasurement(event: string, obj: any): void;
    decorateAll(tags: ITelemetryTagsPayload): void;
    setTelemetryEnabled(enabled: boolean): void;
    aggregateStats(data: Array<number>): IAggregateStats;
    sendEvents(): Promise<boolean>;
    trackFeatureIsUsed(name: string): void;
}
export {};
